all.Litcitms<-function(){
     cat("\n")
     note_for_Litcit_input()
     cat("\n")
     note_for_close_window()
     LitcitMSpar<-data.frame(subject=c(1,2),age=c(0),f=c(0),bw=c(0),Scr=c(0),D=c(0),tau=c(0),c=c(0))
     LitcitMSpar<-edit(LitcitMSpar)
##     LitcitMSpar<-ymscheck(LitcitMSpar)
     cat("\n")
     Litcit.ms(length(LitcitMSpar$subject),LitcitMSpar$c,LitcitMSpar$tau,LitcitMSpar$age,LitcitMSpar$D,LitcitMSpar$Scr,LitcitMSpar$bw,LitcitMSpar$f)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Litcit_output()
     show(samplesStats("*"))
     cat("\n")
     C<-Litcitcpr(LitcitMSpar$D,LitcitMSpar$tau)  
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mEq/L)")
     show(coutput)  
     cat("\n")   
     cal.again()
}